==> qtjambi-xml-5.15.9-sources.jar: io/qt/xml/QXmlEntityResolver.java <==
package io.qt.xml;


/**
 * <p>Interface to resolve external entities contained in XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html">QXmlEntityResolver</a></p>
 */
@Deprecated
public interface QXmlEntityResolver extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlEntityResolver}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlEntityResolver
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlEntityResolver.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId){
                return resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), publicId, systemId);
            }
            private native static io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(long __this__nativeId, java.lang.String publicId, java.lang.String systemId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlEntityResolver instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#errorString">QXmlEntityResolver::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#resolveEntity">QXmlEntityResolver::resolveEntity(QString,QString,QXmlInputSource&amp;*)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId);
        
        private native static io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(long __this__nativeId, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#errorString">QXmlEntityResolver::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#resolveEntity">QXmlEntityResolver::resolveEntity(QString,QString,QXmlInputSource*&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId);
    
    public static final class ResolvedEntity {
    
            public final @io.qt.NativeAccess boolean error;
            public final @io.qt.NativeAccess QXmlInputSource inputSource;
    
            @io.qt.NativeAccess
            public ResolvedEntity(boolean error, QXmlInputSource inputSource) {
    
                this.error = error;
                this.inputSource = inputSource;
    
            }
    
    }
}

==> qtjambi-xml-5.15.13-sources.jar: io/qt/xml/QXmlEntityResolver.java <==
package io.qt.xml;


/**
 * <p>Interface to resolve external entities contained in XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html">QXmlEntityResolver</a></p>
 */
@Deprecated
public interface QXmlEntityResolver extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlEntityResolver}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlEntityResolver
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlEntityResolver.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId){
                return resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), publicId, systemId);
            }
            private native static io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(long __this__nativeId, java.lang.String publicId, java.lang.String systemId);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlEntityResolver instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#errorString">QXmlEntityResolver::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#resolveEntity">QXmlEntityResolver::resolveEntity(QString,QString,QXmlInputSource&amp;*)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId);
        
        private native static io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity_native_cref_QString_cref_QString_ref_QXmlInputSource_ptr(long __this__nativeId, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#errorString">QXmlEntityResolver::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlentityresolver.html#resolveEntity">QXmlEntityResolver::resolveEntity(QString,QString,QXmlInputSource*&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.xml.QXmlEntityResolver.ResolvedEntity resolveEntity(java.lang.String publicId, java.lang.String systemId);
    
    public static final class ResolvedEntity {
    
            public final @io.qt.NativeAccess boolean error;
            public final @io.qt.NativeAccess QXmlInputSource inputSource;
    
            @io.qt.NativeAccess
            public ResolvedEntity(boolean error, QXmlInputSource inputSource) {
    
                this.error = error;
                this.inputSource = inputSource;
    
            }
    
    }
}
